

 /*+-------------------------------------------------------+
   |  SAS Global Forum 2010 Sample                         |
   |  SAS MAPPING: Proc Geocode                            |          
   |                                                       |
   |    NAME: IP_geocode.sas                               |
   |   TITLE: Geocode using RANGE method.  This example    |
   |          uses inputs IP addresses and returns the     |
   |          lat/long position along with the city and    |
   |          country.  The lookup data set must be        |
   |          downloaded and processed according to the    |
   |          instructions below.                          |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |    Proc GEOCODE: Now with Street-Level geocoding      |
   |                                                       |
   |14Jan2010                                              |
   +-------------------------------------------------------+*/

/*************************************************************
 * Before running this program, make sure you:
 * 1. Download the MaxMind lookup data.  Instructions below.
 * 2. Specify the libname LOOKUP for the location of the
 *    MaxMind lookup data.
 ************************************************************/

/*************************************************************
 * Address data.  Weblog or other source of IP addresses.
 *************************************************************/
data weblog;
   cust_ID        = _n_;      /* Assign customer ID number */
   input IPaddress  $ 1-14;   /* IP address                */
cards;
149.173.5.196
213.130.121.235
74.6.22.101
67.85.164.170
149.173.5.7
71.61.6.177
167.176.6.8
71.188.175.30
66.206.246.227
65.110.29.86
;

/*************************************************************
 * Lookup data. Using MaxMind IP address data.
 *************************************************************
 * First, Download the MaxMind GeoLite City CVS file from:
 *        http://www.maxmind.com/app/geolitecity
 * Next, Process the file with the %MAXMIND() autocall macro.
 * Note that 2 data sets are used with range data.  RANGEDATA 
 * contains the range of values and has a key linking to the
 * LOOKUP data.  The lookup data contains the actual lat/long
 * values and is linked by the key.  The lookup data set may 
 * contain other attribute variables such as the city and 
 * country.
 * Finally, set the LOOKUP libname to point to the imported
 * data sets.
 *************************************************************/
libname LOOKUP '<specify-location-of-imported-MaxMind-data>';


/*************************************************************
 * Proc GEOCODE. Perform RANGE geocoding and add the city  
 * and country attributes to the output data.
 *************************************************************/
proc geocode 
     range                        /* Geocoding method       */
     out=work.IPlocations         /* Geolocated output data */

     data=weblog                  /* IP address input data  */
     addressvar=IPaddress         /* Variable in input data */

     rangedata=lookup.cityblocks  /* Range data             */
     beginrangevar=startipnum     /* Variable in rangedata - begin range  */
     endrangevar=endipnum         /* Variable in rangedata - end range    */
     rangekeyvar=locid            /* Key Variable that ties to lookup data*/

     lookup=lookup.citylocation   /* Lookup data             */
     lookupkeyvar=locid           /* Key variable linking to range data   */
     lookupyvar=latitude          /* X variable name         */
     lookupxvar=longitude         /* Y variable name         */
     attributevar=(city,country); /* Additional vars wanted  */
run;
quit;
