
 /*+-------------------------------------------------------+
   |  SAS Global Forum 2010 Sample                         |
   |  SAS MAPPING: Proc Geocode                            |          
   |                                                       |
   |    NAME: ZIP4_geocode.sas                             |
   |   TITLE: Geocode using PLUS4 method.  This example    |
   |          uses inputs addresses and returns the        |
   |          lat/long position along with additional      |
   |          variables as requested.                      |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |    Proc GEOCODE: Now with Street-Level geocoding      |
   |                                                       |
   |14Jan2010                                              |
   +-------------------------------------------------------+*/

/*************************************************************
 * Before running this program, make sure you:
 * 1. Download the TIGER/Census data lookup data from the 
 *    SAS MapsOnLine website as explained below.
 * 2. Specify the libname LOOKUP for the location of the
 *    downloaded lookup data.
 ************************************************************/


/*************************************************************
 * Address data.  Generate Customer addresses.
 *************************************************************/
/*--- Create address data for Delaware customers. */
data work.customers;
   length expected $ 30;
   input address  $ 1-23       /* House number and street name */
         customer $ 24-48      /* Customer name                */
         zip                   /* Customer ZIP Code (numeric)  */
         plus4                 /* ZIP+4 (numeric)              */
         city     $ 60-75      /* City name                    */
         state    $ 76-77      /* State abbreviation           */
         revenue               /* Total revenue for customer   */
         expected $ 87-117;    /* Expected geocoding result    */
   format revenue dollar9.0;   /* Show revenue in dollars      */
   cust_ID        = _n_;       /* Assign customer ID number    */
   label expected='Expected Geocoding Match';
cards;
 136 E. Water St       J. Cheever Loophole      19901 3630 Dover              985.33  ZIP mean: No PLUS4 match
 760 Moose Lodge Road  Cuthbert J. Twillie      19934 2220 Camden             2533.25 ZIP mean: No PLUS4 match
 200 S. Madison Str    Prof. Quincy Wagstaff    19801    . Wilmington      DE 1899.45 ZIP mean: PLUS4 missing
4701 Limestone Road    Kaspar Gutman            19808 1927 Wilmington         33.44   ZIP+4
 252 N 4th St          Dr. Hugo Z. Hackenbush   19363 1735 Oxford          PA 987.02  ZIP+4
 133 Silver Lake Dr    Charlie Allnut           19971 2277 Rehoboth Beach  DE 1459.65 ZIP mean: No PLUS4 match
  11 SE Front Street   Larson E. Whipsnade      19963 1941 Milford         DE 4566.98 ZIP mean: No PLUS4 match
 402 Nylon Boulevard   Guillermo Ugarte             . 2208 Seaford         DE 17.45   None: missing ZIP
 363 E Commerce St     Dewey, Cheatem & Howe        . 1507 Smyrna          DE 989.20  None: missing ZIP
  55 Polly Branch Rd   Capt. Geoffrey Spaulding 19975 7504 Selbyville      DE 1798.33 ZIP mean
1209 Coastal Highway   Joel Cairo               19944 4401 Fenwick Island  DE 2566.45 ZIP mean: No PLUS4 match
2899 Arthursville Rd   Charles Blutoski         19953 3141 Hartly          DE 783.25  ZIP+4
  41 Bramhall St       Fred C. Dobbs                .    .                 DE 898.25  None: missing ZIP & PLUS4
9320 Old Racetrack Rd  Rufus T. Firefly             .    . Delmar          DE 123.45  None: missing ZIP & PLUS4
 123 Cooper Street     Otis B. Driftwood        19955   53 Kenton             98.56   ZIP: Single ZIP code match
 125 Blue Ball Road    Gordon Miller            21921 5335 Elkton          MD 661.13  ZIP+4
4668 Turkey Point Rd   Duke Mantee              19980 9998 Woodside        DE 4531.87 ZIP: Single ZIP code match
;
run;

/****************************************************************
 * Lookup Data. This example uses TIGER/Line Census data available
 * from the SAS MapsOnLine website. You must download and
 * proc CIMPORT this data before running this program.  
 * Set the libname below to the location of the imported data.
 ****************************************************************/
libname lookup '<specify-location-of-TIGER-lookup-data>';


/****************************************************************
 * Proc GEOCODE. Run with the ZIP geocode method to return ZIP4
 * centroids or ZIP centroids.  Don't process CITY.                                              
 ****************************************************************/
/* Notes:                                                       */
/* 1. Uses the specified Census TIGER data lookup file specified*/
/*    above.                                                    */
/* 2. This example adds census track, block, fips, fename and   */
/*    fetype from lookup dataset with the ATTRIBUTEVAR= option. */
/****************************************************************/
proc geocode
     plus4                 /* Geocoding Method   */  
     lookup=lookup.zip4    /* Lookup data set    */
     data=work.customers   /* Input address data */
     out=work.geocoded     /* Output data set    */
     attributevar=(tract block fips fename fetype) /* Added output variables */
     nocity;               /* Only do ZIP4 or ZIP, not CITY */
run;
quit;


/****************************************************************/
/* Uncomment the code below to create a map.                    */
/****************************************************************/
/***
%include 'mapdel.sas';
%mapdel(png,work.geocoded);
***/
