

 /*+-------------------------------------------------------+
   |  SAS Global Forum 2010 Sample                         |
   |  SAS MAPPING: Proc Geocode                            |          
   |                                                       |
   |    NAME: ZIP_geocode.sas                              |
   |   TITLE: Geocode using ZIP method.  This example      |
   |          uses inputs ZIP addresses and returns the    |
   |          lat/long position along with the MSA and     |
   |          areacode.                                    |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |    Proc GEOCODE: Now with Street-Level geocoding      |
   |                                                       |
   |14Jan2010                                              |
   +-------------------------------------------------------+*/

/*************************************************************
 * Address data.  Generate Customer addresses.
 *************************************************************/
data WORK.CUSTOMERS (label='Customer data for geocoding');
  input address $ 1-23       /* House number and street name */
  customer      $ 24-48      /* Customer name                */
  zip                        /* Customer ZIP Code (numeric)  */
  city          $ 55-70      /* City name                    */
  state         $ 71-72      /* State abbreviation           */
  revenue;                   /* Total revenue for customer   */
  format revenue dollar9.0;  /* Show revenue in dollars      */
  label revenue = 'Revenue'; /* Label appears on map legend  */
  cust_ID = _n_;             /* Assign customer ID number    */
cards;
555 Junk Street        Fred G. Sanford          99999 Beverly Hills   CA -25.00
115 E. Water St        J. Cheever Loophole      19901 Dover              985.33
760 Moose Lodge Road   Cuthbert J. Twillie      19934 Camden             2533.25
200 S. Madison Str     Prof. Quincy Wagstaff    19801 Wilmington      DE 1899.45
4701 Limestone Road    Kaspar Gutman            19808 Wilmington         33.44
2117 N 4th St          Dr. Hugo Z. Hackenbush   19363 Oxford          PA 987.02
1313 Mockingbird Lane  Herman Munster               . Delray          CC 233.99
133 Silver Lake Dr     Charlie Allnut           19971 Rehoboth Beach  DE 1459.65
11 SE Front Street     Larson E. Whipsnade      19963 Milford         DE 4566.98
402 Nylon Boulevard    Guillermo Ugarte             . Seaford         DE 17.45
363 E Commerce St      Dewey, Cheatem & Howe        . Smyrna          DE 989.20
5595 Polly Branch Rd   Capt. Geoffrey Spaulding 19975 Selbyville      DE 1798.33
1209 Coastal Highway   Joel Cairo               19944 Fenwick Island  DE 2566.45
2899 Arthursville Rd   Charles Blutoski         19953 Hartly          DE 783.25
41 Bramhall St         Fred C. Dobbs                .                    898.25
9320 Old Racetrack Rd  Rufus T. Firefly             . Delmar          DE 123.45
281 W Commerce Str     Otis B. Driftwood        19955 Kenton             98.56
211 Blue Ball Road     Gordon Miller            21921 Elkton          MD 661.13
3893 Turkey Point Rd   Duke Mantee              19980 Woodside        DE 4531.87
;
run;

/****************************************************************
 * Lookup Data. This example uses SASHELP.ZIPCODE which ships 
 * with SAS, so no extra processing is needed.  Note that 
 * quarterly updates to the ZIPCODE data set are available on the
 * MapsOnLine website: http://support.sas.com/MapsOnLine
 ****************************************************************/


/****************************************************************
 * Proc GEOCODE. Run with the ZIP geocode method to return ZIP
 * code centroids or city locations.                                              
 ****************************************************************/
/* Notes:                                                       */
/* 1. Because the address data set and the lookup data set use  */
/*    the default variable names it is not necessary to use     */
/*    options like ADDRESSZIPVAR= or LOOKUPZIPVAR=              */
/* 2. This example adds MSA and AREACODE data from the          */
/*    lookup dataset with the ATTRIBUTEVAR= option.             */
/****************************************************************/
proc geocode
   zip                            /* Geocoding method      */
   data=work.customers            /* Input address data    */
   out=work.geocoded              /* Output data set       */
   attribute_var=(msa areacode);  /* Added ouput variables */
run;
quit;


/****************************************************************/
/* Uncomment the code below to create a map.                    */
/****************************************************************/
/***
%include 'mapdel.sas';
%mapdel(png,work.geocoded);
***/
