
 /*+-------------------------------------------------------+
   |  SAS Global Forum 2010 Sample                         |
   |  SAS MAPPING: Proc Geocode                            |          
   |                                                       |
   |    NAME: city_geocode.sas                             |
   |   TITLE: Geocode using CITY method.  Return only city |
   |          locations.  This example also uses the       |
   |          ATTRIBUTEVAR= option to return additional    |
   |          variables from the lookup data set on a match|
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |    Proc GEOCODE: Now with Street-Level geocoding      |
   |                                                       |
   |14Jan2010                                              |
   +-------------------------------------------------------+*/
/****************************************************************
 * Address Data. Create a small address data set - Delaware.
 ****************************************************************/
data CUSTOMERS;
   input address  $ 1-23       /* House number and street name */
         customer $ 24-48      /* Customer name                */
         zip                   /* Customer ZIP Code (numeric)  */
         plus4                 /* ZIP+4 (numeric)              */
         city     $ 60-75      /* City name                    */
         state    $ 76-77      /* State abbreviation           */
         revenue               /* Total revenue for customer   */
         expected $ 87-112;    /* Expected geocoding result    */
   format revenue dollar9.0;   /* Show revenue in dollars      */
   cust_ID        = _n_;       /* Assign customer ID number    */
cards;
 136 E. Water St       J. Cheever Loophole      19901 3630 Dover              985.33
 760 Moose Lodge Road  Cuthbert J. Twillie      19934 2220 Camden             2533.25
 200 S. Madison Str    Prof. Quincy Wagstaff    19801    . Wilmington      DE 1899.45
4701 Limestone Road    Kaspar Gutman            19808 1927 Wilmington         33.44
 252 N 4th St          Dr. Hugo Z. Hackenbush   19363 1735 Oxford          PA 987.02
 133 Silver Lake Dr    Charlie Allnut           19971 2277 Rehoboth Beach  DE 1459.65
  11 SE Front Street   Larson E. Whipsnade      19963 1941 Milford         DE 4566.98
 402 Nylon Boulevard   Guillermo Ugarte             . 2208 Seaford         DE 17.45
 363 E Commerce St     Dewey, Cheatem & Howe        . 1507 Smyrna          DE 989.20 
  55 Polly Branch Rd   Capt. Geoffrey Spaulding 19975 7504 Selbyville      DE 1798.33
1209 Coastal Highway   Joel Cairo               19944 4401 Fenwick Island  DE 2566.45 
2899 Arthursville Rd   Charles Blutoski         19953 3141 Hartly          DE 783.25  
  41 Bramhall St       Fred C. Dobbs                .    .                 DE 898.25
9320 Old Racetrack Rd  Rufus T. Firefly             .    . Delmar          DE 123.45
 123 Cooper Street     Otis B. Driftwood        19955   53 Kenton             98.56
 125 Blue Ball Road    Gordon Miller            21921 5335 Elkton          MD 661.13
4668 Turkey Point Rd   Duke Mantee              19980 9998 Woodside        DE 4531.87
;
run;

/****************************************************************
 * Lookup Data. This example uses SASHELP.ZIPCODE which ships 
 * with SAS, so no extra processing is needed.  Note that 
 * quarterly updates to the ZIPCODE data set are available on the
 * MapsOnLine website: http://support.sas.com/MapsOnLine
 ****************************************************************/

/****************************************************************/
/* Proc GEOCODE. Run with the CITY geocode method to return only*/
/* city locations.                                              */
/****************************************************************/
/* Notes:                                                       */
/* 1. Because the address data set and the lookup data set use  */
/*    the default variable names it is not necessary to use     */
/*    options like ADDRESSCITYVAR= or LOOKUPCITYVAR=            */
/* 2. This example adds MSA and AREACODE data from the          */
/*    lookup dataset with the ATTRIBUTEVAR= option.             */
/****************************************************************/
proc geocode
   city                          /*city method*/
   data=work.customers           /*address data to geocode*/
   out=work.geocoded
   lookup=sashelp.zipcode        /*lookup data set to use*/
   attribute_var=(msa areacode); /*Added attribute variables*/
run;
quit;

/****************************************************************/
/* Uncomment the code below to create a map.                    */
/****************************************************************/
/***
%include 'mapdel.sas';
%mapdel(png,work.geocoded);
***/

