
 /*+-------------------------------------------------------+
   |  SAS Global Forum 2010 Sample                         |
   |  SAS MAPPING: Proc Geocode                            |          
   |                                                       |
   |    NAME: custom_geocode.sas                           |
   |   TITLE: Geocode using CUSTOM method.  This example   |
   |          creates a custom lookup data set from the    |
   |          SASHELP.ZIPCODE that contains the locations  |
   |          of the telephone areacodes.  And then        |
   |          geocoding with that data.                    |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |    Proc GEOCODE: Now with Street-Level geocoding      |
   |                                                       |
   |14Jan2010                                              |
   +-------------------------------------------------------+*/

/*************************************************************
 * Address Data.  Create customer data to geocode by AREACODE
 * with the CUSTOM geocode method.
 *************************************************************/
data WORK.CUSTOMERS (label='Input data for geocoding with CUSTOM var');
  input customer     $  1-24   /* Customer name               */
        areacode               /* Customer's Area Code        */
        revenue;               /* Revenue from customer       */
  format Revenue dollar9.0; 
  cust_ID = _n_;
cards;
Fred G. Sanford           999    25.00
J. Cheever Loophole       386   985.33
Cuthbert J. Twillie       904   2533.25
Prof. Quincy Wagstaff     904   1899.45
Kaspar Gutman             352   33.44
Dr. Hugo Z. Hackenbush    352   987.02
Herman Munster              .   233.99
Charlie Allnut            804   1459.65
Larson E. Whipsnade       386   4566.98
Guillermo Ugarte            .   17.45
Dewey, Cheatem & Howe       .   989.20
Capt. Geoffrey Spaulding  850   1798.33
Joel Cairo                352   2566.45
Charles Blutoski          850   783.25
Fred C. Dobbs               .   898.25
Rufus T. Firefly          407   123.45
Otis B. Driftwood         321   98.56
Gordon Miller             407   661.13
Duke Mantee               772   4531.87
;
run;

/*************************************************************
 * Lookup data.  Create a custom lookup data set by averaging
 * the locations of the AREACODE variable in SASHELP.ZIPCODE
 *************************************************************/
proc sort data=sashelp.zipcode out=temp; 
   by areacode; 
run;
proc means data=temp noprint;
   by areacode;
   label x='Mean Longitude of Area Code'
         y='Mean Latitude of Area Code'
         areacode='Area Code';
   var x y;
   output mean= out=work.areacodes (keep=x y areacode label='Area Code Centers');
run;

/*************************************************************
 * Proc GEOCODE. CUSTOM Geocode by AREACODE variable.
 *************************************************************/
proc geocode
   custom                      /* Custom Geocoding method     */
   data       = customers      /* Input data set to geocode   */
   out        = geocoded       /* Geocoded output data set    */
   lookup     = work.areacodes /* Lookup data set             */
   lookupvar  = areacode       /* Geocode var in lookup data  */
   addressvar = areacode;      /* Customer var to geocode     */
run;
quit;
