 /*+-------------------------------------------------------+
   |  SAS Global Forum 2009 Sample                         |
   |  SAS MAPPING: Proc Geocode                            |          
   |                                                       |
   |    NAME: mapdel.sas                                   |
   |   TITLE: Display a map with points for Delaware.      |
   |          This macro will create maps for data         |
   |          geocoded with ZIP_geocode.sas,               |
   |          ZIP4_geocode.sas and city_geocode.sas.       |
   |          Run by specifying output device and geocoded |
   |          dataset.  Example:                           |
   |          %mapdel(png,work.geocoded);                  |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |    Proc GEOCODE: Creating map location from your data |
   | 11Jan09                                               |
   +-------------------------------------------------------+*/

%macro mapdel(dev,geods); 
   %let name=geomap;        /*html file name*/
   filename odsout '.';     /*html location */
   goptions reset=global ;  /*clear any previous goptions */
   
   /************************************************************/
   /* subset map to only Delaware counties                     */
   /************************************************************/
   data mymap (drop=state);
      set maps.counties;
	if ('DE'=FIPSTATE(state)) then output;
   run;

   /************************************************************/
   /* Convert geocoded data to radians to match this map.      */
   /* Also, drop any observations with missing values for x or */
   /* y because a geocode location was not found.              */
   /************************************************************/
   data mypoints; set &geods;
      anno_flag=1;
      if x ne . and y ne . then do;
        x=atan(1)/45 * x *-1;
        y=atan(1)/45 * y;
      end;
      output;
   run;

   /************************************************************/
   /* Combine the map and annotate data, project it and then   */
   /* split the data sets.                                     */
   /************************************************************/
   data work.combined; /* combine data*/
     set mypoints mymap; 
   run;
   /* gproject both datasets*/
   proc gproject data=work.combined out=work.combined dupok;
       id county;
   run;
   /* split the data*/
   data mymap mypoints;
      set work.combined;
      if anno_flag=1 then output mypoints;
      else output mymap;
   run;

   /************************************************************/
   /* Create an annotate data set of dots for each address x,y */
   /************************************************************/
   data points;
     set mypoints;
     length function style color $ 8 position $ 1 text $ 20 html $1024;
     retain xsys ysys '2' hsys '3' when 'a' text '';

     /* Create a tool-tip for the dot */
     html=
      'alt='||
        quote(
          'Customer: '||trim(left(customer))
          );

     /* Each dot is a small pie.  Set color, size, etc */
     function='pie'; color='red'; size=.6; rotate=360; 
     style='solid'; position='5'; 
     output;
   run;

   /************************************************************/
   /* Create an HTML file showing the map and points.          */
   /************************************************************/
   GOPTIONS DEVICE=&dev;
   ODS LISTING CLOSE;
   ODS HTML path=odsout body="&name._&dev..html"
      style=statistical
    ;
   pattern v=s c=CXE9E8DC r=100;
   goptions border;

   proc gmap map=mymap anno=points data=mymap;  
        id county;  
        choro county /nolegend;
   run;
   quit;
   ODS HTML CLOSE;
   ODS LISTING;
%mend;
