

 /*+-------------------------------------------------------+
   |  SAS Global Forum 2010 Sample                         |
   |  SAS MAPPING: Proc Geocode                            |          
   |                                                       |
   |    NAME: street_geocode.sas                           |
   |   TITLE: Geocode using STREET method.  This example   |
   |          uses inputs Street addresses and returns the |
   |          lat/long position along with the Census Tract|
   |          and a bunch of varibles indicating the status|
   |          of the geocoding of the address.             |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |    Proc GEOCODE: Now with Street-Level geocoding      |
   |                                                       |
   |14Jan2010                                              |
   +-------------------------------------------------------+*/

/*************************************************************
 * This example will run with the sample LOOKUP data already
 * installed in SASHELP (GEOEXM, GEOEXS and GEOEXP) and works 
 * only for addresses in Wake County in North Carolina.
 * Before running this program on US data, you should:
 * 1. Download the real US lookup data (USM, USS, and USP)
 *    from the SAS MapsOnLine website. www.sas.com/mapsonline
 * 2. Either install the files in SASHELP or create a libname
 *    to the data set location to use with the LOOKUPSTREET=
 *    option of Proc GEOCODE.
 ************************************************************/

/*************************************************************
 * Address data.  Generate Customer addresses.
 *************************************************************/
data WORK.CUSTOMERS (label='Customer data for geocoding');
  input address $ 1-23       /* House number and street name */
  customer      $ 24-48      /* Customer name                */
  zip                        /* Customer ZIP Code (numeric)  */
  city          $ 55-70      /* City name                    */
  state         $ 71-72      /* State abbreviation           */
  revenue;                   /* Total revenue for customer   */
  format revenue dollar9.0;  /* Show revenue in dollars      */
  label revenue = 'Revenue'; /* Label appears on map legend  */
  cust_ID = _n_;             /* Assign customer ID number    */
cards;
555 Junk Street        Fred G. Sanford          99999 Beverly Hills   CA -25.00
305 Cross Lake Drive   J. Cheever Loophole      27526 Fuquay-Varina   NC 985.33
2525 Banks Road        Cuthbert J. Twillie      27603 Raleigh         NC 2533.25
2222 SAS Campus Drive  Prof. Quincy Wagstaff    27513 Cary            NC 1899.45
1150 SE Maynard Rd.    Kaspar Gutman            27511 Cary            NC 33.44
2117 Graceland Dr.     Hugo Z. Hackenbush       27606 Raleigh         NC 987.02
1313 Mockingbird Lane  Herman Munster               . Delray          CC 233.99
133 Jade Circle        Charlie Allnut           27545 Knightdale      NC 1459.65
1005 W South St        Larson E. Whipsnade      27603 Raleigh         NC 4566.98
N Winds North Drive    Guillermo Ugarte         27591 Wendell         NC 17.45
622 Roundabout Road    Dewey, Cheatem & Howe    27540 Holly Springs   NC 989.20
Johnson Family Rd      Capt. Geoffrey Spaulding 27526                    1798.33
822 Water Plant Road   Joel Cairo                     Zebulon         NC 2566.45
502 Possum Track Road  Charles Blutoski         27614                 NC 783.25
2590 Wolfpack Lane     Fred C. Dobbs            27604 Raleigh         NC 898.25
125 Ferris Wheel Ct    Rufus T. Firefly         27513 Cary            NC 123.45
1822 Watertown Circle  Otis B. Driftwood            . Raleigh         NC 98.56
;
run;


/****************************************************************
 * Lookup Data. This example uses example street-level lookup
 * data already installed in SASHELP.  Processing real addresses
 * will require the street lookup data sets be downloaded from
 * the SAS MapsOnLine website.
 * http://support.sas.com/rnd/datavisualization/mapsonline/html/geocode.html
 * You must download and proc CIMPORT this data.  If you don't
 * install the data sets in SAS help, you must create a libname
 * to use with the LOOKUPSTREET= option.  
 ****************************************************************/
 * libname lookup '<specify-location-of-TIGER-lookup-data>';

/****************************************************************
 * Proc GEOCODE. Run with the STREET geocode method to return 
 * Street address, ZIP Code centroids or city locations.                                              
 ****************************************************************/
/* Note:                                                        */
/* This example adds Census Tract to the output                 */
/****************************************************************/
proc geocode
   method=STREET                  /* Geocoding method      */
   data=work.customers            /* Input address data    */
   out=work.geocoded              /* Output data set       */
   lookupstreet=SASHELP.GEOEXM
   attribute_var=(TRACTCE00);     /* Added ouput variables */
run;
quit;


/****************************************************************/
/* Uncomment the code below to create a map.                    */
/****************************************************************/
/***
%include 'mapwakenc.sas';
%mapwakenc(png,work.geocoded);
***/